<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

if ($cambia_soprannome and $nome_squadra_cambiabile == "SI") {
$nuovo_soprannome = htmlentities($nuovo_soprannome);
$nuovo_soprannome = strip_tags($nuovo_soprannome);
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra = $soprannome_squadra[3];
if ($nuovo_soprannome == $soprannome_squadra) $inserire = "NO";
next($pass);
} # fine for $num1
if (strlen($nuovo_soprannome) <= 20 and $inserire != "NO") {
$lock = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
flock($lock,2);
$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 4) { $num_linee = 4; }
$linee[3] = $nuovo_soprannome;
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,togli_acapo($linee[$num1])."
");
} # fine for $num1
flock($filesquadra,3);
flock($lock,3);
fclose($filesquadra);
fclose($lock);
} # fine if (strlen($nuovo_soprannome) <= 20 and...)
} # fine if ($cambia_soprannome and $nome_squadra_cambiabile == "SI")

if ($cambia_homepage and $indirizzo_sito_squadra_cambiabile == "SI") {
if ($inserire_url != "NO") {
$lock = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
flock($lock,2);
$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 5) { $num_linee = 5; }
$linee[4] = $nuova_home_page;
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,togli_acapo($linee[$num1])."
");
} # fine for $num1
flock($filesquadra,3);
flock($lock,3);
fclose($filesquadra);
fclose($lock);
} # fine if (strlen($nuovo_soprannome) <= 20 and...)
} # fine if ($cambia_homepage and $indirizzo_sito_squadra_cambiabile == "SI")



$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

if ($nome_squadra == $giocatore or $nome_squadra == "tutti") {

$dati_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra = $dati_squadra[3];
$soprannome_squadra = togli_acapo($soprannome_squadra);
echo "<center><font size=+1>";
if ($soprannome_squadra) echo "<b>$soprannome_squadra</b>";
else echo "Squadra";
echo " di $giocatore</font></center>";
$contatore_calciatori = 0;
$lista_calciatori = "";
$soldi_spesi = 0;
$num_calciatori_posseduti = 0;
$linea_offerto = "";
$linea_comprato_P = array();
$linea_comprato_D = array();
$linea_comprato_C = array();
$linea_comprato_F = array();
$linea_comprato_A = array();
$tab_comprati = "";
$tab_offerte = "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td><font size=-1>Costo</font></td>
<td>__Tempo_rimasto__</td></tr>";

$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num2 = 0 ; $num2 < $num_calciatori ; $num2++) {
$dati_calciatore = explode(",", $calciatori[$num2]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $giocatore) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$lista_calciatori[$contatore_calciatori] = $numero;
$contatore_calciatori++;
$nome_linea = "linea_comprato_$ruolo";
${$nome_linea}[$numero] = "<tr><td>&nbsp;</td>
<td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo</td>";
if ($giocatore == $nome_utente) {
${$nome_linea}[$numero] .= "<td><input type=\"radio\" name=\"schierato$numero\" value=\"titolare\"></td>
<td><input type=\"radio\" name=\"schierato$numero\" value=\"panchinaro\">
<select name=\"panchinaro$numero\">";
${$nome_linea}[$numero] .= "<option value=\"-\">-</option>";
for ($num3 = 1 ; $num3 <= $max_in_panchina ; $num3++) {
${$nome_linea}[$numero] .= "<option value=\"$num3\">$num3</option>";
} # fine for $num3
${$nome_linea}[$numero] .= "</select></td>
<td><input type=\"radio\" name=\"schierato$numero\" value=\"fuori\"></td>
<td><a href=\"vendi.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">vendi</a></td>";
} # fine if ($giocatore == $nome_utente)
${$nome_linea}[$numero] .= "</tr>";
} # fine if ($sec_restanti < 0)
else { 
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";
$nuovo_costo = $dati_calciatore[8];
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
$tab_offerte .= "<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo_mostra</td>
<td>$tempo_restante</td></tr>";
} # fine else if ($sec_restanti < 0)
} # fine if ($proprietario == $giocatore)
} # fine for $num2

if ($giocatore == $nome_utente) { echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"seleziona_squadra.php\">"; }
echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td><font size=-2>Pos.</font></td>
<td><font size=-2>Num.</font></td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td><font size=-1>Costo</font></td>";
$colspan = 5;
if ($giocatore == $nome_utente) {
echo "<td><font size=-2>titolare</font></td><td><font size=-0>__panchina__</font></td><td><font size=-2>fuori</font></td><td>&nbsp;</td>";
$colspan = 9;
} # fine if ($giocatore == $nome_utente)
echo "</tr>
<tr><td align=\"center\" colspan=\"$colspan\">Titolari</td></tr>";
$titolari = explode(",", $dati_squadra[1]);

# tabella dei titolari
$num_titolari = count($titolari);
$tab_titolari_P = "";
$tab_titolari_D = "";
$tab_titolari_C = "";
$tab_titolari_F = "";
$tab_titolari_A = "";
$inserito = array();
$num_pos = 1;
for ($num2 = 0 ; $num2 < $num_titolari ; $num2++) {
$numero_titolare = $titolari[$num2];
if ($linea_comprato_P[$numero_titolare]) {
$linea_comprato_P[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_P[$numero_titolare]);
$linea_comprato_P[$numero_titolare] = preg_replace("|<tr><td>&nbsp;<\/td>|","<tr><td>$num_pos</td>",$linea_comprato_P[$numero_titolare]);
$num_pos++;
$tab_titolari_P .= $linea_comprato_P[$numero_titolare];
$inserito[$numero_titolare] = "SI";
} # fine if ($linea_comprato_P[$numero_titolare])
if ($linea_comprato_D[$numero_titolare]) {
$linea_comprato_D[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_D[$numero_titolare]);
$linea_comprato_D[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_D[$numero_titolare]);
$num_pos++;
$tab_titolari_D .= $linea_comprato_D[$numero_titolare];
$inserito[$numero_titolare] = "SI";
} # fine if ($linea_comprato_D[$numero_titolare])
if ($linea_comprato_C[$numero_titolare]) {
$linea_comprato_C[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_C[$numero_titolare]);
$linea_comprato_C[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_C[$numero_titolare]);
$num_pos++;
$tab_titolari_C .= $linea_comprato_C[$numero_titolare];
$inserito[$numero_titolare] = "SI";
} # fine if ($linea_comprato_C[$numero_titolare])
if ($linea_comprato_F[$numero_titolare]) {
$linea_comprato_F[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_F[$numero_titolare]);
$linea_comprato_F[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_titolare]);
$num_pos++;
$tab_titolari_F .= $linea_comprato_F[$numero_titolare];
$inserito[$numero_titolare] = "SI";
} # fine if ($linea_comprato_F[$numero_titolare])
if ($linea_comprato_A[$numero_titolare]) {
$linea_comprato_A[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_A[$numero_titolare]);
$linea_comprato_A[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_titolare]);
$num_pos++;
$tab_titolari_A .= $linea_comprato_A[$numero_titolare];
$inserito[$numero_titolare] = "SI";
} # fine if ($linea_comprato_A[$numero_titolare])
} # fine for $num2
echo $tab_titolari_P.$tab_titolari_D.$tab_titolari_C.$tab_titolari_F.$tab_titolari_A;

# Tabella dei panchinari
echo "<tr><td align=\"center\" colspan=\"$colspan\">In panchina</td></tr>";
$panchinari = explode(",", $dati_squadra[2]);
$num_panchinari = count($panchinari);
$tab_panchinari_P = "";
$tab_panchinari_D = "";
$tab_panchinari_C = "";
$tab_panchinari_F = "";
$tab_panchinari_A = "";
$tab_panchinari = "";
for ($num2 = 0 ; $num2 < $num_panchinari ; $num2++) {
$numero_panchinaro = $panchinari[$num2];
$num_in_panchina = $num2 + 1;
if ($linea_comprato_P[$numero_panchinaro]) {
$linea_comprato_P[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_P[$numero_panchinaro]);
$linea_comprato_P[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_P[$numero_panchinaro]);
$linea_comprato_P[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_P[$numero_panchinaro]);
$num_pos++;
$tab_panchinari .= $linea_comprato_P[$numero_panchinaro];
$inserito[$numero_panchinaro] = "SI";
} # fine if ($linea_comprato_P[$numero_panchinaro])
if ($linea_comprato_D[$numero_panchinaro]) {
$linea_comprato_D[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_D[$numero_panchinaro]);
$linea_comprato_D[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_D[$numero_panchinaro]);
$linea_comprato_D[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_D[$numero_panchinaro]);
$num_pos++;
$tab_panchinari .= $linea_comprato_D[$numero_panchinaro];
$inserito[$numero_panchinaro] = "SI";
} # fine if ($linea_comprato_D[$numero_panchinaro])
if ($linea_comprato_C[$numero_panchinaro]) {
$linea_comprato_C[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_C[$numero_panchinaro]);
$linea_comprato_C[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_C[$numero_panchinaro]);
$linea_comprato_C[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_C[$numero_panchinaro]);
$num_pos++;
$tab_panchinari .= $linea_comprato_C[$numero_panchinaro];
$inserito[$numero_panchinaro] = "SI";
} # fine if ($linea_comprato_C[$numero_panchinaro])
if ($linea_comprato_F[$numero_panchinaro]) {
$linea_comprato_F[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_F[$numero_panchinaro]);
$linea_comprato_F[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_F[$numero_panchinaro]);
$linea_comprato_F[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_panchinaro]);
$num_pos++;
$tab_panchinari .= $linea_comprato_F[$numero_panchinaro];
$inserito[$numero_panchinaro] = "SI";
} # fine if ($linea_comprato_F[$numero_panchinaro])
if ($linea_comprato_A[$numero_panchinaro]) {
$linea_comprato_A[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_A[$numero_panchinaro]);
$linea_comprato_A[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_A[$numero_panchinaro]);
$linea_comprato_A[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_panchinaro]);
$num_pos++;
$tab_panchinari .= $linea_comprato_A[$numero_panchinaro];
$inserito[$numero_panchinaro] = "SI";
} # fine if ($linea_comprato_A[$numero_panchinaro])
} # fine for $num2
#echo $tab_panchinari_P.$tab_panchinari_D.$tab_panchinari_C.$tab_panchinari_A;
echo $tab_panchinari;

# Tabella degli esclusi
echo "<tr><td align=\"center\" colspan=\"$colspan\">Fuori rosa</td></tr>";
$tab_fuori_P = "";
$tab_fuori_D = "";
$tab_fuori_C = "";
$tab_fuori_F = "";
$tab_fuori_A = "";
$num_calciatori = count($lista_calciatori);
for ($num2 = 0 ; $num2 < $num_calciatori ; $num2++) {
$numero_fuori = $lista_calciatori[$num2];
if ($inserito[$numero_fuori] != "SI") {
if ($linea_comprato_P[$numero_fuori]) {
$linea_comprato_P[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_P[$numero_fuori]);
$tab_fuori_P .= $linea_comprato_P[$numero_fuori];
$inserito[$numero_fuori] = "SI";
} # fine if ($linea_comprato_P[$numero_fuori])
if ($linea_comprato_D[$numero_fuori]) {
$linea_comprato_D[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_D[$numero_fuori]);
$tab_fuori_D .= $linea_comprato_D[$numero_fuori];
$inserito[$numero_fuori] = "SI";
} # fine if ($linea_comprato_D[$numero_fuori])
if ($linea_comprato_C[$numero_fuori]) {
$linea_comprato_C[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_C[$numero_fuori]);
$tab_fuori_C .= $linea_comprato_C[$numero_fuori];
$inserito[$numero_fuori] = "SI";
} # fine if ($linea_comprato_C[$numero_fuori])
if ($linea_comprato_F[$numero_fuori]) {
$linea_comprato_F[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_F[$numero_fuori]);
$tab_fuori_F .= $linea_comprato_F[$numero_fuori];
$inserito[$numero_fuori] = "SI";
} # fine if ($linea_comprato_F[$numero_fuori])
if ($linea_comprato_A[$numero_fuori]) {
$linea_comprato_A[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_A[$numero_fuori]);
$tab_fuori_A .= $linea_comprato_A[$numero_fuori];
$inserito[$numero_fuori] = "SI";
} # fine if ($linea_comprato_A[$numero_fuori])
} # fine if ($inserito[$num_fuori] != "SI")
} # fine for $num2
echo $tab_fuori_P.$tab_fuori_D.$tab_fuori_C.$tab_fuori_F.$tab_fuori_A;

echo "</table>";

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$dati_giocatore = @file("$percorso_cartella_dati/squadra_$giocatore");
$surplus = $dati_giocatore[0];
$home_page_squadra = togli_acapo($dati_giocatore[4]);
if (!$home_page_squadra) $home_page_squadra_vedi = "http://";
else $home_page_squadra_vedi = $home_page_squadra;
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;

if ($giocatore == $nome_utente) {
for ($num2 = "01" ; $num2 < 100 ; $num2++) {
if (strlen($num2) == 1) $num2 = "0".$num2;
$giornata = "$percorso_cartella_dati/giornata$num2";
if (!@is_file($giornata)) break;
} # fine for $num2
echo "<center><br>
<input type=\"submit\" name=\"cambia_formazione\" value=\"Cambia la formazione per la giornata $num2\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
</center></form>";
if ($nome_squadra_cambiabile == "SI") {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
<input type=\"submit\" name=\"cambia_soprannome\" value=\"Cambia il nome\">
 della squadra in <input type=\"text\" name=\"nuovo_soprannome\" size=\"20\" maxlength=\"20\" value=\"$soprannome_squadra\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_squadra\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
</form>";
} # fine if ($nome_squadra_cambiabile == "SI")
if ($indirizzo_sito_squadra_cambiabile == "SI") {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
<input type=\"submit\" name=\"cambia_homepage\" value=\"Cambia l'indirizzo\">
 della pagina ufficiale in <input type=\"text\" name=\"nuova_home_page\" size=\"20\" maxlength=\"50\" value=\"$home_page_squadra_vedi\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_squadra\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
</form>";
} # fine if ($indirizzo_sito_squadra_cambiabile == "SI")
} # fine if ($giocatore == $nome_utente)

echo "<table width =\"100%\"><tr><td align=\"left\">
Soldi ancora da spendere: <b>$soldi_spendibili</b> Fanta-Euro.<br>
Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.</td>";
if (@is_file("$percorso_cartella_dati/$giocatore.jpg") or $home_page_squadra) {
echo "<td align=\"left\">";
if ($home_page_squadra) echo "<a href=\"$home_page_squadra\" target=\"_blank\">";
if (@is_file("$percorso_cartella_dati/$giocatore.jpg")) echo "<img src=\"$percorso_cartella_dati/$giocatore.jpg\" alt=\"Pagina ufficiale di $giocatore\" border=\"0\">";
else echo "Pagina ufficiale";
if ($home_page_squadra) echo "</a>";
echo "</td>";
} # fine if (@is_file("$percorso_cartella_dati/$giocatore.jpg") or $home_page_squadra)
echo "</tr></table>";

echo "<center>Offerte in corso</center>";
$tab_offerte .= "</table>";
echo $tab_offerte;

echo "<hr width=\"95%\">";


} # fine if ($nome_squadra == $giocatore or $nome_squadra == "tutti")

next($pass);
} # fine for $num1

echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>


